"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.tool_type import ToolType


class TestToolType(unittest.TestCase):
    """ToolType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testToolType(self):
        """Test ToolType"""
        ToolType("type")


if __name__ == '__main__':
    unittest.main()
