"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
globals()['TextPhysicalAddressAnnotation'] = TextPhysicalAddressAnnotation
from nlpsandbox.model.text_physical_address_annotation_response import TextPhysicalAddressAnnotationResponse


class TestTextPhysicalAddressAnnotationResponse(unittest.TestCase):
    """TextPhysicalAddressAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextPhysicalAddressAnnotationResponse(self):
        """Test TextPhysicalAddressAnnotationResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextPhysicalAddressAnnotationResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
