"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
globals()['TextPersonNameAnnotation'] = TextPersonNameAnnotation
from nlpsandbox.model.text_person_name_annotation_response import TextPersonNameAnnotationResponse


class TestTextPersonNameAnnotationResponse(unittest.TestCase):
    """TextPersonNameAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextPersonNameAnnotationResponse(self):
        """Test TextPersonNameAnnotationResponse"""
        TextPersonNameAnnotationResponse(
            text_person_name_annotations=[
                TextPersonNameAnnotation(start=10, length=10, text="foobar", confidence=95.5)
            ]
        )


if __name__ == '__main__':
    unittest.main()
