"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_covid_symptom_annotation_all_of import TextCovidSymptomAnnotationAllOf


class TestTextCovidSymptomAnnotationAllOf(unittest.TestCase):
    """TextCovidSymptomAnnotationAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextCovidSymptomAnnotationAllOf(self):
        """Test TextCovidSymptomAnnotationAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextCovidSymptomAnnotationAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
