"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.masking_char_config import MaskingCharConfig


class TestMaskingCharConfig(unittest.TestCase):
    """MaskingCharConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMaskingCharConfig(self):
        """Test MaskingCharConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MaskingCharConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
