"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import nlpsandbox
from nlpsandbox.api.deidentified_note_api import DeidentifiedNoteApi  # noqa: E501


class TestDeidentifiedNoteApi(unittest.TestCase):
    """DeidentifiedNoteApi unit test stubs"""

    def setUp(self):
        self.api = DeidentifiedNoteApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_deidentified_notes(self):
        """Test case for create_deidentified_notes

        Deidentify a clinical note  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
