# flake8: noqa

"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.2
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from nlpsandbox.api_client import ApiClient

# import Configuration
from nlpsandbox.configuration import Configuration

# import exceptions
from nlpsandbox.exceptions import OpenApiException
from nlpsandbox.exceptions import ApiAttributeError
from nlpsandbox.exceptions import ApiTypeError
from nlpsandbox.exceptions import ApiValueError
from nlpsandbox.exceptions import ApiKeyError
from nlpsandbox.exceptions import ApiException
