"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_contact_annotation import TextContactAnnotation
from nlpsandbox.model.text_date_annotation import TextDateAnnotation
from nlpsandbox.model.text_id_annotation import TextIdAnnotation
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
globals()['TextContactAnnotation'] = TextContactAnnotation
globals()['TextDateAnnotation'] = TextDateAnnotation
globals()['TextIdAnnotation'] = TextIdAnnotation
globals()['TextPersonNameAnnotation'] = TextPersonNameAnnotation
globals()['TextPhysicalAddressAnnotation'] = TextPhysicalAddressAnnotation
from nlpsandbox.model.annotation_set import AnnotationSet


class TestAnnotationSet(unittest.TestCase):
    """AnnotationSet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAnnotationSet(self):
        """Test AnnotationSet"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AnnotationSet()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
