"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_covid_symptom_annotation import TextCovidSymptomAnnotation
globals()['TextCovidSymptomAnnotation'] = TextCovidSymptomAnnotation
from nlpsandbox.model.text_covid_symptom_annotation_response import TextCovidSymptomAnnotationResponse


class TestTextCovidSymptomAnnotationResponse(unittest.TestCase):
    """TextCovidSymptomAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextCovidSymptomAnnotationResponse(self):
        """Test TextCovidSymptomAnnotationResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextCovidSymptomAnnotationResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
