"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch, Mock

import nlpsandbox
from nlpsandbox.api.annotation_store_api import AnnotationStoreApi  # noqa: E501


class TestAnnotationStoreApi(unittest.TestCase):
    """AnnotationStoreApi unit test stubs"""

    def setUp(self):
        self.api = AnnotationStoreApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_annotation_store(self):
        """Test case for create_annotation_store

        Create an annotation store  # noqa: E501
        """
        self.api.create_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store",
            body={}
        )

    def test_delete_annotation_store(self):
        """Test case for delete_annotation_store

        Delete an annotation store  # noqa: E501
        """
        self.api.delete_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store"
        )

    def test_get_annotation_store(self):
        """Test case for get_annotation_store

        Get an annotation store  # noqa: E501
        """
        self.api.get_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store"
        )

    def test_list_annotation_stores(self):
        """Test case for list_annotation_stores

        List the annotation stores in a dataset  # noqa: E501
        """
        self.api.list_annotation_stores(
            dataset_id="dataset"
        )


if __name__ == '__main__':
    unittest.main()
